@@ -19,7 +19,13 @@ except ImportError:
         return x
 
 
-__version__ = "1.11.4"
+### hack to make sure this module is not placed in root CIRCUITPY/lib folder
+if "." not in __name__:
+    raise ImportError(
+        "seesaw neopixel being imported from unexpected location - is seesaw neopixel use intended?"
+    )
+
+__version__ = "1.11.5"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_seesaw.git"
 
 _NEOPIXEL_BASE = const(0x0E)
